==> haskell-yesod-static-1.6.1.0-967-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-DraZT8ngEP36vSJiPp4yYw
key:                  yesod-static-1.6.1.0-DraZT8ngEP36vSJiPp4yYw
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  71dc94852ecf50181cd15f802ce35c4c
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-DraZT8ngEP36vSJiPp4yYw
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    cryptonite-0.30-5QYVWJr24zH1Zlsr0wVxCr
    cryptonite-conduit-0.2.2-9LnsVKvLTo2BzSKDWt6ZJh
    css-text-0.1.3.0-EabfuOGZPIdI0loquvBori
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hjsmin-0.2.1-DJkPitA070X2jhBSAPswR5
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART process-1.6.19.0
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-app-static-3.1.9-5YuV7YlKgoJECZOZIgHDZ
    yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-static-1.6.1.0-968-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-static
version:              1.6.1.0
visibility:           public
id:                   yesod-static-1.6.1.0-3qfjjxIJZN3r519Uk6gYp
key:                  yesod-static-1.6.1.0-3qfjjxIJZN3r519Uk6gYp
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Static file serving subsite for Yesod Web Framework.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-static>

category:             Web, Yesod
abi:                  b8490cf17158f0c9718bfea96a916985
exposed:              True
exposed-modules:
    Yesod.EmbeddedStatic Yesod.EmbeddedStatic.Css.AbsoluteUrl
    Yesod.EmbeddedStatic.Generators Yesod.EmbeddedStatic.Types
    Yesod.Static

hidden-modules:
    Yesod.EmbeddedStatic.Internal Yesod.EmbeddedStatic.Css.Util

import-dirs:          /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yesod-static-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-static
hs-libraries:         HSyesod-static-1.6.1.0-3qfjjxIJZN3r519Uk6gYp
depends:
    async-2.2.5-6z3frWRfGJJLLgOv3gEskc
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    blaze-builder-0.4.4.1-3Jo4fZFJ11sJTzGUvOFfLv bytestring-0.11.5.3
    conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh containers-0.6.7
    cryptonite-0.30-5QYVWJr24zH1Zlsr0wVxCr
    cryptonite-conduit-0.2.2-9LnsVKvLTo2BzSKDWt6ZJh
    css-text-0.1.3.0-EabfuOGZPIdI0loquvBori
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    hjsmin-0.2.1-DJkPitA070X2jhBSAPswR5
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    mime-types-0.1.2.0-2lnuHjhOzQ4DFNhuFJ9ART process-1.6.19.0
    template-haskell-2.20.0.0 text-2.0.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    wai-app-static-3.1.9-5YuV7YlKgoJECZOZIgHDZ
    yesod-core-1.6.27.1-KtBa6Xls8994lQw12Q4B1F

haddock-interfaces:
    /usr/share/doc/haskell-yesod-static/html/yesod-static.haddock

haddock-html:         /usr/share/doc/haskell-yesod-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
